@@ -2,13 +2,12 @@
 
 
 function clean {
-  local verbose=''
-
   OPTIND=1
 
+  # shellcheck disable=2034
   while getopts 'vh' opt; do
     case "$opt" in
-      v) verbose="v";;
+      v) _SECRETS_VERBOSE=1;;
 
       h) _show_manual_for 'clean';;
 
@@ -19,8 +18,12 @@ function clean {
   shift $((OPTIND-1))
   [ "$1" = '--' ] && shift
 
+  if [ $# -ne 0 ]; then 
+    _abort "clean does not understand params: $*"
+  fi
+
   _user_required
 
-  # User should see properly formated output:
-  _find_and_clean_formated "*$SECRETS_EXTENSION" "$verbose"
+  # User should see properly formatted output:
+  _find_and_clean_formatted "*$SECRETS_EXTENSION"
 }
