@@ -33,11 +33,9 @@ function remove {
     normalized_path=$(_git_normalize_filename "$item")
     path=$(_append_root_path "$normalized_path")
 
-    echo "$item -> $normalized_path -> $path"
-
     # Checking if file exists:
     if [[ ! -f "$path" ]]; then
-      _abort "$item is not a file."
+      _abort "file not found: $item"
     fi
 
     # Deleting it from path mappings:
@@ -58,6 +56,6 @@ function remove {
     fi
   done
 
-  echo 'removed from index.'
-  echo "ensure that files: [$*] are now not ignored."
+  echo 'git-secret: removed from index.'
+  echo "git-secret: ensure that files: [$*] are now not ignored."
 }
